@@ -57,6 +57,7 @@ const (
 func NewSkaffoldCommand(out, err io.Writer) *cobra.Command {
 	updateMsg := make(chan string, 1)
 	surveyPrompt := make(chan bool, 1)
+	metricsPrompt := make(chan bool, 1)
 
 	rootCmd := &cobra.Command{
 		Use: "skaffold",
@@ -74,6 +75,14 @@ func NewSkaffoldCommand(out, err io.Writer) *cobra.Command {
 			instrumentation.SetCommand(cmd.Use)
 
 			out = color.SetupColors(out, defaultColor, forceColors)
+			if timestamps {
+				l := logrus.New()
+				l.SetOutput(out)
+				l.SetFormatter(&logrus.TextFormatter{
+					DisableTimestamp: false,
+				})
+				out = l.Writer()
+			}
 			cmd.Root().SetOutput(out)
 
 			// Setup logs
@@ -111,6 +120,7 @@ func NewSkaffoldCommand(out, err io.Writer) *cobra.Command {
 						updateMsg <- msg
 					}
 					surveyPrompt <- config.ShouldDisplayPrompt(opts.GlobalConfig)
+					metricsPrompt <- instrumentation.ShouldDisplayMetricsPrompt(opts.GlobalConfig)
 				}()
 			}
 			return nil
@@ -131,6 +141,15 @@ func NewSkaffoldCommand(out, err io.Writer) *cobra.Command {
 				}
 			default:
 			}
+			select {
+			case showMetricsPrompt := <-metricsPrompt:
+				if showMetricsPrompt {
+					if err := instrumentation.DisplayMetricsPrompt(opts.GlobalConfig, cmd.OutOrStdout()); err != nil {
+						fmt.Fprintf(cmd.OutOrStderr(), "%v\n", err)
+					}
+				}
+			default:
+			}
 		},
 	}
 
