@@ -23,7 +23,6 @@ import (
 	"os"
 
 	"github.com/spf13/cobra"
-	"github.com/spf13/pflag"
 
 	"github.com/GoogleContainerTools/skaffold/cmd/skaffold/app/flags"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/build"
@@ -47,9 +46,9 @@ func NewCmdFilter() *cobra.Command {
 		WithDescription("[alpha] Filter and transform a set of Kubernetes manifests from stdin").
 		WithLongDescription("Unlike `render`, this command does not build artifacts.").
 		WithCommonFlags().
-		WithFlags(func(f *pflag.FlagSet) {
-			f.VarP(&renderFromBuildOutputFile, "build-artifacts", "a", "File containing build result from a previous 'skaffold build --file-output'")
-			f.BoolVar(&debuggingFilters, "debugging", false, `Apply debug transforms similar to "skaffold debug"`)
+		WithFlags([]*Flag{
+			{Value: &renderFromBuildOutputFile, Name: "build-artifacts", Shorthand: "a", Usage: "File containing build result from a previous 'skaffold build --file-output'"},
+			{Value: &debuggingFilters, Name: "debugging", DefValue: false, Usage: `Apply debug transforms similar to "skaffold debug"`, IsEnum: true},
 		}).
 		NoArgs(func(ctx context.Context, out io.Writer) error {
 			return doFilter(ctx, out, debuggingFilters, renderFromBuildOutputFile.BuildArtifacts())
@@ -59,7 +58,7 @@ func NewCmdFilter() *cobra.Command {
 // runFilter loads the Kubernetes manifests from stdin and applies the debug transformations.
 // Unlike `skaffold debug`, this filtering affects all images and not just the built artifacts.
 func runFilter(ctx context.Context, out io.Writer, debuggingFilters bool, buildArtifacts []build.Artifact) error {
-	return withRunner(ctx, func(r runner.Runner, cfg *latest.SkaffoldConfig) error {
+	return withRunner(ctx, out, func(r runner.Runner, configs []*latest.SkaffoldConfig) error {
 		manifestList, err := manifest.Load(os.Stdin)
 		if err != nil {
 			return fmt.Errorf("loading manifests: %w", err)
@@ -70,7 +69,7 @@ func runFilter(ctx context.Context, out io.Writer, debuggingFilters bool, buildA
 			if err != nil {
 				return fmt.Errorf("resolving debug helpers: %w", err)
 			}
-			insecureRegistries, err := getInsecureRegistries(opts, cfg)
+			insecureRegistries, err := getInsecureRegistries(opts, configs)
 			if err != nil {
 				return fmt.Errorf("retrieving insecure registries: %w", err)
 			}
@@ -88,12 +87,17 @@ func runFilter(ctx context.Context, out io.Writer, debuggingFilters bool, buildA
 	})
 }
 
-func getInsecureRegistries(opts config.SkaffoldOptions, cfg *latest.SkaffoldConfig) (map[string]bool, error) {
+func getInsecureRegistries(opts config.SkaffoldOptions, configs []*latest.SkaffoldConfig) (map[string]bool, error) {
 	cfgRegistries, err := config.GetInsecureRegistries(opts.GlobalConfig)
 	if err != nil {
 		return nil, err
 	}
-	regList := append(opts.InsecureRegistries, cfg.Build.InsecureRegistries...)
+	var regList []string
+
+	regList = append(regList, opts.InsecureRegistries...)
+	for _, cfg := range configs {
+		regList = append(regList, cfg.Build.InsecureRegistries...)
+	}
 	regList = append(regList, cfgRegistries...)
 	insecureRegistries := make(map[string]bool, len(regList))
 	for _, r := range regList {
