@@ -119,7 +119,7 @@ func (r *imageReplacer) Visit(o map[string]interface{}, k string, v interface{})
 func (r *imageReplacer) Check() {
 	for imageName := range r.tagsByImageName {
 		if !r.found[imageName] {
-			warnings.Printf("image [%s] is not used by the deployment", imageName)
+			logrus.Debugf("image [%s] is not used by the current deployment", imageName)
 		}
 	}
 }
