@@ -20,9 +20,11 @@ import (
 	"bytes"
 	"errors"
 	"fmt"
+	"io"
 	"strings"
 
 	"github.com/sirupsen/logrus"
+	"gopkg.in/yaml.v3"
 
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/apiversion"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/kubernetes"
@@ -56,6 +58,7 @@ import (
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/v2alpha3"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/v2alpha4"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/v2beta1"
+	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/v2beta10"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/v2beta2"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/v2beta3"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/v2beta4"
@@ -65,7 +68,6 @@ import (
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/v2beta8"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/v2beta9"
 	misc "github.com/GoogleContainerTools/skaffold/pkg/skaffold/util"
-	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/yaml"
 )
 
 type APIVersion struct {
@@ -109,6 +111,7 @@ var SchemaVersions = Versions{
 	{v2beta7.Version, v2beta7.NewSkaffoldConfig},
 	{v2beta8.Version, v2beta8.NewSkaffoldConfig},
 	{v2beta9.Version, v2beta9.NewSkaffoldConfig},
+	{v2beta10.Version, v2beta10.NewSkaffoldConfig},
 	{latest.Version, latest.NewSkaffoldConfig},
 }
 
@@ -143,54 +146,25 @@ func IsSkaffoldConfig(file string) bool {
 }
 
 // ParseConfig reads a configuration file.
-func ParseConfig(filename string) (util.VersionedConfig, error) {
+func ParseConfig(filename string) ([]util.VersionedConfig, error) {
 	buf, err := misc.ReadConfiguration(filename)
 	if err != nil {
 		return nil, fmt.Errorf("read skaffold config: %w", err)
 	}
-
-	// This is to quickly check that it's possibly a skaffold.yaml,
-	// without parsing the whole file.
-	if !bytes.Contains(buf, []byte("apiVersion")) {
-		return nil, errors.New("missing apiVersion")
+	factories, err := configFactoryFromAPIVersion(buf)
+	if err != nil {
+		return nil, err
 	}
-
-	apiVersion := &APIVersion{}
-	if err := yaml.Unmarshal(buf, apiVersion); err != nil {
-		return nil, fmt.Errorf("parsing api version: %w", err)
-	}
-
-	factory, present := SchemaVersions.Find(apiVersion.Version)
-	if !present {
-		return nil, fmt.Errorf("unknown api version: %q", apiVersion.Version)
-	}
-
-	// Remove all top-level keys starting with `.` so they can be used as YAML anchors
-	parsed := make(map[string]interface{})
-	if err := yaml.UnmarshalStrict(buf, parsed); err != nil {
-		return nil, fmt.Errorf("unable to parse YAML: %w", err)
-	}
-	for field := range parsed {
-		if strings.HasPrefix(field, ".") {
-			delete(parsed, field)
-		}
-	}
-	buf, err = yaml.Marshal(parsed)
+	buf, err = removeYamlAnchors(buf)
 	if err != nil {
 		return nil, fmt.Errorf("unable to re-marshal YAML without dotted keys: %w", err)
 	}
-
-	cfg := factory()
-	if err := yaml.UnmarshalStrict(buf, cfg); err != nil {
-		return nil, fmt.Errorf("unable to parse config: %w", err)
-	}
-
-	return cfg, nil
+	return parseConfig(buf, factories)
 }
 
 // ParseConfigAndUpgrade reads a configuration file and upgrades it to a given version.
-func ParseConfigAndUpgrade(filename, toVersion string) (util.VersionedConfig, error) {
-	cfg, err := ParseConfig(filename)
+func ParseConfigAndUpgrade(filename, toVersion string) ([]util.VersionedConfig, error) {
+	configs, err := ParseConfig(filename)
 	if err != nil {
 		return nil, err
 	}
@@ -199,32 +173,121 @@ func ParseConfigAndUpgrade(filename, toVersion string) (util.VersionedConfig, er
 	if _, present := SchemaVersions.Find(toVersion); !present {
 		return nil, fmt.Errorf("unknown api version: %q", toVersion)
 	}
-
-	// Check that the config's version is not newer than the target version
-	currentVersion, err := apiversion.Parse(cfg.GetVersion())
-	if err != nil {
-		return nil, err
-	}
-	targetVersion, err := apiversion.Parse(toVersion)
-	if err != nil {
-		return nil, err
-	}
-
-	if currentVersion.EQ(targetVersion) {
-		return cfg, nil
-	}
-	if currentVersion.GT(targetVersion) {
-		return nil, fmt.Errorf("config version %q is more recent than target version %q: upgrade Skaffold", cfg.GetVersion(), toVersion)
-	}
-
-	logrus.Debugf("config version %q out of date: upgrading to latest %q", cfg.GetVersion(), toVersion)
-
-	for cfg.GetVersion() != toVersion {
-		cfg, err = cfg.Upgrade()
+	upgradeNeeded := false
+	for _, cfg := range configs {
+		// Check that the config's version is not newer than the target version
+		currentVersion, err := apiversion.Parse(cfg.GetVersion())
 		if err != nil {
-			return nil, fmt.Errorf("transforming skaffold config: %w", err)
+			return nil, err
+		}
+		targetVersion, err := apiversion.Parse(toVersion)
+		if err != nil {
+			return nil, err
+		}
+
+		if currentVersion.NE(targetVersion) {
+			upgradeNeeded = true
+		}
+		if currentVersion.GT(targetVersion) {
+			return nil, fmt.Errorf("config version %q is more recent than target version %q: upgrade Skaffold", cfg.GetVersion(), toVersion)
 		}
 	}
+	if !upgradeNeeded {
+		return configs, nil
+	}
+	logrus.Debugf("config version out of date: upgrading to latest %q", toVersion)
 
-	return cfg, nil
+	var upgraded []util.VersionedConfig
+	for _, cfg := range configs {
+		for cfg.GetVersion() != toVersion {
+			cfg, err = cfg.Upgrade()
+			if err != nil {
+				return nil, fmt.Errorf("transforming skaffold config: %w", err)
+			}
+		}
+		upgraded = append(upgraded, cfg)
+	}
+	return upgraded, nil
+}
+
+// configFactoryFromAPIVersion checks that all configs in the input stream have the same API version, and returns a function to create a config with that API version.
+func configFactoryFromAPIVersion(buf []byte) ([]func() util.VersionedConfig, error) {
+	// This is to quickly check that it's possibly a skaffold.yaml,
+	// without parsing the whole file.
+	if !bytes.Contains(buf, []byte("apiVersion")) {
+		return nil, errors.New("missing apiVersion")
+	}
+
+	var factories []func() util.VersionedConfig
+	b := bytes.NewReader(buf)
+	decoder := yaml.NewDecoder(b)
+	for {
+		var v APIVersion
+		err := decoder.Decode(&v)
+		if err == io.EOF {
+			break
+		}
+		if err != nil {
+			return nil, fmt.Errorf("parsing api version: %w", err)
+		}
+		factory, present := SchemaVersions.Find(v.Version)
+		if !present {
+			return nil, fmt.Errorf("unknown api version: %q", v.Version)
+		}
+		factories = append(factories, factory)
+	}
+	return factories, nil
+}
+
+// removeYamlAnchors removes all top-level keys starting with `.` from the input stream so they can be used as YAML anchors
+func removeYamlAnchors(buf []byte) ([]byte, error) {
+	in := bytes.NewReader(buf)
+	var out bytes.Buffer
+
+	decoder := yaml.NewDecoder(in)
+	decoder.KnownFields(true)
+	encoder := yaml.NewEncoder(&out)
+	for {
+		parsed := make(map[string]interface{})
+		err := decoder.Decode(parsed)
+		if err == io.EOF {
+			break
+		}
+		if err != nil {
+			return nil, fmt.Errorf("unable to parse YAML: %w", err)
+		}
+		for field := range parsed {
+			if strings.HasPrefix(field, ".") {
+				delete(parsed, field)
+			}
+		}
+		err = encoder.Encode(parsed)
+		if err != nil {
+			return nil, err
+		}
+	}
+	err := encoder.Close()
+	if err != nil {
+		return nil, err
+	}
+	return out.Bytes(), nil
+}
+
+func parseConfig(buf []byte, factories []func() util.VersionedConfig) ([]util.VersionedConfig, error) {
+	b := bytes.NewReader(buf)
+	decoder := yaml.NewDecoder(b)
+	decoder.KnownFields(true)
+	var cfgs []util.VersionedConfig
+	for index := 0; index < len(factories); index++ {
+		cfg := factories[index]()
+		err := decoder.Decode(cfg)
+		if err == io.EOF {
+			break
+		}
+		if err != nil {
+			return nil, fmt.Errorf("unable to parse config: %w", err)
+		}
+		cfgs = append(cfgs, cfg)
+	}
+	return cfgs, nil
 }
